@@ -1,4 +1,4 @@
-# (C) Copyright 2008-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2008-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -46,6 +46,9 @@ class SimpleEditor(SimpleTextEditor):
     #: handler.
     _connections_to_remove = List(Tuple(Any(), Callable()))
 
+    #: Wildcard filter to apply to the file dialog:
+    filter = filter_trait
+
     def init(self, parent):
         """Finishes initializing the editor by creating the underlying toolkit
         widget.
@@ -75,6 +78,9 @@ class SimpleEditor(SimpleTextEditor):
 
         self.set_tooltip(control)
 
+        self.filter = self.factory.filter
+        self.sync_value(self.factory.filter_name, "filter", "from", is_list=True)
+
     def dispose(self):
         """Disposes of the contents of an editor."""
         while self._connections_to_remove:
